# mistral_workflows.plugins - Extensible Workflow Components

THERE SHOULD NOT BE AN `__init__.py` FILE IN THIS FOLDER!

This is a [PEP 420](https://peps.python.org/pep-0420/) namespace package.

## What is this?

`mistral_workflows.plugins` is a **PEP420 namespace package** that enables:

- **Reusable workflows**: Pre-built workflow patterns that can be imported and used
- **Reusable activities**: Building blocks for constructing workflows
- **Reusable dependencies**: Common service clients and utilities
